@@ -209,7 +209,7 @@ qic <- function(y,
                 negy         = TRUE,
                 dots.only    = FALSE,
                 multiply     = 1,
-                prime       = FALSE,
+                prime        = FALSE,
                 standardised = FALSE,
                 x.format     = '%Y-%m-%d',
                 nint         = 5,
@@ -389,7 +389,9 @@ qic <- function(y,
     qic$ucl <- c(qic$ucl, y$ucl)
   }
 
-  if(max(table(qic$y) >= length(na.omit(qic$y)) / 2 & chart == 'run')){
+  # Suppress center and control lines in run charts if more than half
+  #  the data points are of the same value
+  if(max(table(qic$y)) >= (length(na.omit(qic$y)) / 2) & type == 'run') {
     qic$cl <- NA
     qic$ucl <- NA
     qic$lcl <- NA
